# sierra

![sierra logo](https://github.com/BrainStormYourWayIn/pyramid/blob/main/logo.jpg)

A lightweight Python framework for building and Integrating Web Applications.
Sierra is a Python3 library for building and integrating web applications with HTML and CSS using simple enough syntax. You can develop your web applications with Python, taking advantage of its functionalities and integrating them to the fullest.

## The second stable release is out

Check out the documentation for added syntax and improved autocomplete  

________________________________

## Documentation

Check out the [Official documentation of Sierra](https://brainstormyourwayin.github.io/sierra.github.io/)

Check out a [comprehensive example](https://github.com/BrainStormYourWayIn/sierra_doc/blob/main/doc.py) of its use

________________________________

### Issues

- We're aware of issues surrounding naming of the HTML and CSS. As of now, the HTML and the CSS are named `index.html` and `style.css` by default.
- We're also aware this can cause conflicts when creating multi-paged web applications unless pages other than the main page are in different folders.
- We're working on this and is going to rectified in the next mini-release that is coming very soon

________________________________

## Installation

### Method 1: pip install

type the below command in terminal:

`pip install sierra`

### Method 2: Download ZIP file

**To download the zip file:** click on the `download` button and then click on the `Download ZIP` button. The zip file will get downloaded in the downloads folder.

**To unzip the zip file:** open the zipped folder, then drag the file or folder from the zipped folder to a new location. To unzip all the contents of the zipped folder, press and hold (or right-click) the folder, select `Extract All`. Development can be done in `sierra-main/sierra` and not in `sierra-main/``src/sierra`
Check out [doc.py](https://github.com/BrainStormYourWayIn/sierra_doc/blob/main/doc.py) for a better view on how to start off

### Method 3: Clone repository

To clone the repository, type:

`gh repo clone BrainStormYourWayIn/sierra`
or
`git clone https://github.com/BrainStormYourWayIn/sierra.git`

in your terminal/shell.

________________________________

## Under development

**Upcoming:**

- Support for markdown
- Official support for [brython over JS](https://brython.info)

________________________________

## License

   Copyright 2021 BrainStormYourWayIn

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

Pandas (pandas)

Copyright (c) 2008-2011, AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2011-2020, Open source contributors.
